@@ -9,4 +9,19 @@ $p->handler($h);
 foreach my $xmlfile (@ARGV) {
     $p->parse($xmlfile);
 }
+__END__
+
+=head1 NAME
+
+stag-xml2itext - converts between stag formats
+
+=head1 DESCRIPTION
+
+Converts from xml to itext format.
+
+=head1 SEE ALSO
+
+L<Data::Stag>
+
+=cut
 
